@@ -27,6 +27,12 @@
 #include <glib/gi18n.h>
 #include "interface.h"
 
+#if !GTK_CHECK_VERSION(2,22,0)
+#define GDK_KEY_Delete GDK_Delete
+#define GDK_KEY_Escape GDK_Escape
+#define GDK_KEY_W GDK_W
+#endif
+
 GtkTreeStore *list_store;
 GtkTreeSelection *selection;
 GtkWidget *treeview;
@@ -52,6 +58,11 @@ extern gint refresh_interval;
 extern guint rID;
 GtkWidget *refresh_spin;
 
+const char *details (void)
+{
+  return full_view ? _("Less details") : _("More details");
+}
+
 GtkWidget* create_main_window (void)
 {
     GtkWidget *window;
@@ -64,6 +75,7 @@ GtkWidget* create_main_window (void)
     GtkWidget *button3;
 
     GtkWidget *system_info_box;
+    GtkWidget *alignment;
 
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (window), _("Task Manager"));
@@ -88,17 +100,10 @@ GtkWidget* create_main_window (void)
 	item = gtk_image_menu_item_new_from_stock( GTK_STOCK_QUIT, NULL );
 	GtkAccelGroup* accel_group = gtk_accel_group_new();
 	gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
-#if GTK_CHECK_VERSION(3,0,0)
 	gtk_widget_add_accelerator(item, "activate", accel_group,
 		GDK_KEY_Escape, (GdkModifierType)0, GTK_ACCEL_VISIBLE);
 	gtk_widget_add_accelerator(item, "activate", accel_group,
 		GDK_KEY_W, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-#else
-	gtk_widget_add_accelerator(item, "activate", accel_group,
-		GDK_Escape, (GdkModifierType)NULL, GTK_ACCEL_VISIBLE);
-	gtk_widget_add_accelerator(item, "activate", accel_group,
-		GDK_W, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-#endif
 	gtk_menu_shell_append( (GtkMenuShell*)menu, item );
 	g_signal_connect( item, "activate", G_CALLBACK(gtk_main_quit), NULL );
 
@@ -170,23 +175,28 @@ GtkWidget* create_main_window (void)
 
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(list_store), COLUMN_TIME, GTK_SORT_DESCENDING);
 
-    bbox1 = gtk_hbutton_box_new();
+    create_taskpopup(accel_group);
+
+    bbox1 = gtk_table_new(1, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox1), bbox1, FALSE, TRUE, 0);
     gtk_widget_show (bbox1);
 
-    button3 = gtk_toggle_button_new_with_label (_("more details"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button3), full_view);
+    button3 = gtk_button_new_with_label(details());
+    gtk_button_set_focus_on_click(GTK_BUTTON(button3), FALSE);
     gtk_widget_show (button3);
-    gtk_box_pack_start (GTK_BOX (bbox1), button3, FALSE, FALSE, 0);
+    gtk_table_attach(GTK_TABLE(bbox1), button3, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
     button1 = gtk_button_new_from_stock ("gtk-quit");
-    gtk_widget_show (button1);
-    gtk_box_pack_start (GTK_BOX (bbox1), button1, FALSE, FALSE, 0);
+    alignment = gtk_alignment_new(1, 0.5, 0, 0);
+    gtk_container_add(GTK_CONTAINER(alignment), button1);
+    gtk_table_attach(GTK_TABLE(bbox1), alignment, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+    gtk_widget_show_all(alignment);
 
     g_signal_connect ((gpointer) window, "destroy", G_CALLBACK (on_quit), NULL);
     g_signal_connect_swapped ((gpointer) treeview, "button-press-event", G_CALLBACK(on_treeview1_button_press_event), NULL);
+    g_signal_connect(treeview, "popup-menu", G_CALLBACK(on_treeview_popup_menu), NULL);
     g_signal_connect ((gpointer) button1, "clicked",  G_CALLBACK (on_quit),  NULL);
-    g_signal_connect ((gpointer) button3, "toggled",  G_CALLBACK (on_button3_toggled_event),  NULL);
+    g_signal_connect ((gpointer) button3, "clicked",  G_CALLBACK (on_button3_toggled_event),  NULL);
 
     return window;
 }
@@ -224,7 +234,7 @@ void create_list_store(void)
     cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(cell_renderer, "xalign", 1.0, NULL);
 
-    column[2] = gtk_tree_view_column_new_with_attributes(_("CPU%"), cell_renderer, "text", COLUMN_TIME, NULL);
+    column[2] = gtk_tree_view_column_new_with_attributes(_("CPU"), cell_renderer, "text", COLUMN_TIME, NULL);
     if (column_width[2] > 0)
     {
       gtk_tree_view_column_set_sizing(column[2], GTK_TREE_VIEW_COLUMN_FIXED);
@@ -232,7 +242,7 @@ void create_list_store(void)
     }
     gtk_tree_view_column_set_resizable(column[2], TRUE);
     gtk_tree_view_column_set_sort_column_id(column[2], COLUMN_TIME);
-    gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(list_store), COLUMN_TIME, compare_int_list_item, GUINT_TO_POINTER(COLUMN_TIME), NULL);
+    gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(list_store), COLUMN_TIME, compare_double_list_item, GUINT_TO_POINTER(COLUMN_TIME), NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column[2]);
 
     column[3] = gtk_tree_view_column_new_with_attributes(_("RSS"), cell_renderer, "text", COLUMN_RSS, NULL);
@@ -304,9 +314,8 @@ void create_list_store(void)
     change_list_store_view();
 }
 
-GtkWidget* create_taskpopup (void)
+void create_taskpopup (GtkAccelGroup *accel_group)
 {
-    GtkWidget *taskpopup;
     GtkWidget *menu_item;
 
     taskpopup = gtk_menu_new ();
@@ -322,11 +331,15 @@ GtkWidget* create_taskpopup (void)
     g_signal_connect ((gpointer) menu_item, "activate", G_CALLBACK (handle_task_menu), "CONT");
 
     menu_item = gtk_menu_item_new_with_mnemonic (_("Term"));
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group,
+        GDK_KEY_Delete, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
     gtk_widget_show (menu_item);
     gtk_container_add (GTK_CONTAINER (taskpopup), menu_item);
     g_signal_connect ((gpointer) menu_item, "activate", G_CALLBACK (handle_task_menu), "TERM");
 
     menu_item = gtk_menu_item_new_with_mnemonic (_("Kill"));
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group,
+        GDK_KEY_Delete, GDK_SHIFT_MASK, GTK_ACCEL_VISIBLE);
     gtk_widget_show (menu_item);
     gtk_container_add (GTK_CONTAINER (taskpopup), menu_item);
     g_signal_connect ((gpointer) menu_item, "activate", G_CALLBACK (handle_task_menu), "KILL");
@@ -335,8 +348,6 @@ GtkWidget* create_taskpopup (void)
     gtk_menu_item_set_submenu((gpointer) menu_item, create_prio_submenu());
     gtk_widget_show (menu_item);
     gtk_container_add (GTK_CONTAINER (taskpopup), menu_item);
-
-    return taskpopup;
 }
 
 GtkWidget *create_prio_submenu(void)
@@ -462,7 +473,7 @@ void show_about_dialog(void)
 #endif
     /* gtk_about_dialog_set_logo( (GtkAboutDialog*)about_dlg, gdk_pixbuf_new_from_file(  PACKAGE_DATA_DIR"/pixmaps/lxtask.png", NULL ) ); */
     gtk_about_dialog_set_logo_icon_name( (GtkAboutDialog*)about_dlg, "utilities-system-monitor" );
-    gtk_about_dialog_set_copyright ( (GtkAboutDialog*)about_dlg, _( "Copyright (C) 2008-2024 LXDE team" ) );
+    gtk_about_dialog_set_copyright ( (GtkAboutDialog*)about_dlg, _( "Copyright (C) 2008-2025 LXDE team" ) );
     gtk_about_dialog_set_comments ( (GtkAboutDialog*)about_dlg, _( "Lightweight task manager for LXDE project" ) );
     gtk_about_dialog_set_license ( (GtkAboutDialog*)about_dlg, "This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA." );
     gtk_about_dialog_set_website ( (GtkAboutDialog*)about_dlg, "http://lxde.org/" );
@@ -509,7 +520,8 @@ void fill_list_item(guint i, GtkTreeIter *iter)
         gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_RSS, size_to_string(buf, (task->rss)*1024), -1);
 
         gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_UNAME, task->uname, -1);
-        sprintf(buf,"%0d%%", (guint)task->time_percentage);
+        /* TRANSLATORS: If it is customary, insert a space before the double percent sign. */
+        sprintf(buf, _("%0.1f%%"), task->time_percentage);
         gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_TIME, buf, -1);
         sprintf(buf,"%d",task->prio);
         gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_PRIO, buf, -1);    /* my change */
@@ -590,6 +602,28 @@ gint compare_int_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIter
     return i1 - i2;
 }
 
+gint compare_double_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIter *iter2, gpointer column)
+{
+    gchar *s1;
+    gchar *s2;
+
+    gtk_tree_model_get(model, iter1, GPOINTER_TO_UINT(column), &s1, -1);
+    gtk_tree_model_get(model, iter2, GPOINTER_TO_UINT(column), &s2, -1);
+
+    gdouble d1 = 0.0;
+    gdouble d2 = 0.0;
+
+    if(s1 != NULL)
+        d1 = atof(s1);
+    if(s2 != NULL)
+        d2 = atof(s2);
+
+    g_free(s1);
+    g_free(s2);
+
+    return (d1 > d2) - (d1 < d2);
+}
+
 gint compare_size_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIter *iter2, gpointer column)
 {
     gchar *s1;
@@ -679,12 +713,16 @@ void show_preferences(void)
     GtkWidget *c_area;
     GtkWidget *notebook = gtk_notebook_new();
     GtkWidget *general_box = gtk_vbox_new(FALSE, 0);
-    GtkWidget *refresh_box = gtk_hbox_new(FALSE, 0);
+    GtkWidget *refresh_box = gtk_hbox_new(FALSE, 4);
     refresh_spin = gtk_spin_button_new_with_range(1, 60, 1);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(refresh_spin), refresh_interval);
 
     dlg = gtk_dialog_new_with_buttons(_("Preferences"), NULL, 0, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+#if GTK_CHECK_VERSION(2,14,0)
     c_area = gtk_dialog_get_content_area(GTK_DIALOG (dlg));
+#else
+    c_area = GTK_DIALOG(dlg)->vbox;
+#endif
 
     gtk_box_pack_start(GTK_BOX (c_area), notebook, TRUE, TRUE, 0);
     gtk_notebook_append_page(GTK_NOTEBOOK (notebook), general_box, gtk_label_new(_("General")));
