@@ -68,7 +68,7 @@ void change_list_store_view(void);
 void create_list_store(void);
 
 GtkWidget* create_main_window (void);
-GtkWidget* create_taskpopup (void);
+void create_taskpopup (GtkAccelGroup *);
 GtkWidget* create_mainmenu (void);
 GtkWidget *create_prio_submenu(void);
 
@@ -78,6 +78,7 @@ void fill_list_item(guint i, GtkTreeIter *iter);
 void add_new_list_item(guint i);
 gint compare_list_item(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data);
 gint compare_int_list_item(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data);
+gint compare_double_list_item(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data);
 gint compare_size_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIter *iter2, gpointer column);
 gint compare_string_list_item(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data);
 void remove_list_item(pid_t i);
@@ -86,4 +87,6 @@ void refresh_list_item(guint i);
 void change_task_view(void);
 void change_full_path(void);
 
+const char *details(void);
+
 #endif
